Getting Started — django-url2png 0.1 documentation

django-url2png 0.1 documentation

# Getting Started

- Table of Contents
- index
  next
  previous

# Getting Started

1. Install it with `pip`

       pip install django-url2png

2. Configure settings: API_KEY, SECRET_KEY

3. Optionally set optional defaults for the filter, especially THUMBNAIL_MAX_WIDTH

4. Use it in a template

       {% load url2png_tags %}
       <img src="{{ url|url2png:400 }}" width="400" height="{% get_height 400 %}"/>

   This uses the configured `THUMBNAIL_MAX_WIDTH`, which is set to `300`

       {% load url2png_tags %}
       <img src="{{ url|url2png }}" width="300" height="{% get_height %}"/>